@@ -1,5 +1,5 @@
 /* This file is part of the 'stringi' project.
- * Copyright (c) 2013-2021, Marek Gagolewski <https://www.gagolewski.com>
+ * Copyright (c) 2013-2023, Marek Gagolewski <https://www.gagolewski.com/>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -65,7 +65,7 @@ void StriBrkIterOptions::setType(SEXP opts_brkiter, const char* _default) {
         SEXP names = Rf_getAttrib(opts_brkiter, R_NamesSymbol);
         if (names == R_NilValue || LENGTH(names) != narg)
             Rf_error(MSG__INCORRECT_BRKITER_OPTION_SPEC); // error() allowed here
-        // search for "locale" option
+        // search for "type" option
         for (R_len_t i=0; i<narg; ++i) {
             if (STRING_ELT(names, i) == NA_STRING)
                 Rf_error(MSG__INCORRECT_BRKITER_OPTION_SPEC); // error() allowed here
@@ -142,8 +142,7 @@ void StriBrkIterOptions::setLocale(SEXP opts_brkiter) {
                 Rf_error(MSG__INCORRECT_BRKITER_OPTION_SPEC); // error() allowed here
             const char* curname = CHAR(STRING_ELT(names, i));
             if (!strcmp(curname, "locale")) {
-                this->locale = stri__prepare_arg_locale(VECTOR_ELT(opts_brkiter, i),
-                                                        "locale", true); // this is R_alloc'ed
+                this->locale = stri__prepare_arg_locale(VECTOR_ELT(opts_brkiter, i), "locale");  // this is R_alloc'ed
                 return;
             }
         }
@@ -153,7 +152,7 @@ void StriBrkIterOptions::setLocale(SEXP opts_brkiter) {
     }
 
     // otherwise return default locale
-    this->locale = stri__prepare_arg_locale(R_NilValue, "locale", true); /* this is R_alloc'ed */
+    this->locale = stri__prepare_arg_locale(R_NilValue, "locale"); /* this is R_alloc'ed */
 }
 
 
