@@ -1,5 +1,5 @@
 /* This file is part of the 'stringi' project.
- * Copyright (c) 2013-2020, Marek Gagolewski <https://www.gagolewski.com>
+ * Copyright (c) 2013-2023, Marek Gagolewski <https://www.gagolewski.com/>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -59,7 +59,7 @@
  */
 SEXP stri_enc_fromutf32(SEXP vec)
 {
-    PROTECT(vec = stri_prepare_arg_list_integer(vec, "vec"));
+    PROTECT(vec = stri__prepare_arg_list_integer(vec, "vec"));
 
     STRI__ERROR_HANDLER_BEGIN(1)
     StriContainerListInt vec_cont(vec);
@@ -134,7 +134,7 @@ SEXP stri_enc_fromutf32(SEXP vec)
  */
 SEXP stri_enc_toutf32(SEXP str)
 {
-    PROTECT(str = stri_prepare_arg_string(str, "str"));
+    PROTECT(str = stri__prepare_arg_string(str, "str"));
     R_len_t n = LENGTH(str);
 
     STRI__ERROR_HANDLER_BEGIN(1)
@@ -173,9 +173,9 @@ SEXP stri_enc_toutf32(SEXP str)
         }
 
         if (c < 0) {
-            Rf_warning(MSG__INVALID_UTF8);
-            SET_VECTOR_ELT(ret, i, R_NilValue);
-            continue;
+            throw StriException(MSG__INVALID_UTF8);
+//             SET_VECTOR_ELT(ret, i, R_NilValue);
+//             continue;
         }
         else {
             SEXP conv;
@@ -220,10 +220,10 @@ SEXP stri_enc_toutf32(SEXP str)
  */
 SEXP stri_enc_toutf8(SEXP str, SEXP is_unknown_8bit, SEXP validate)
 {
-    PROTECT(validate = stri_prepare_arg_logical_1(validate, "validate"));
+    PROTECT(validate = stri__prepare_arg_logical_1(validate, "validate"));
     bool is_unknown_8bit_logical =
         stri__prepare_arg_logical_1_notNA(is_unknown_8bit, "is_unknown_8bit");
-    PROTECT(str = stri_prepare_arg_string(str, "str"));
+    PROTECT(str = stri__prepare_arg_string(str, "str"));
     R_len_t n = LENGTH(str);
 
     STRI__ERROR_HANDLER_BEGIN(2)
@@ -258,7 +258,7 @@ SEXP stri_enc_toutf8(SEXP str, SEXP is_unknown_8bit, SEXP validate)
 
             if (IS_ASCII(curs) || IS_UTF8(curs)) {
                 R_len_t curs_n = LENGTH(curs);
-                const char* curs_s = CHAR(curs);
+                const char* curs_s = CHAR(curs);  // TODO: ALTREP will be problematic?
                 if (curs_n >= 3 &&
                         (uint8_t)(curs_s[0]) == UTF8_BOM_BYTE1 &&
                         (uint8_t)(curs_s[1]) == UTF8_BOM_BYTE2 &&
@@ -274,7 +274,7 @@ SEXP stri_enc_toutf8(SEXP str, SEXP is_unknown_8bit, SEXP validate)
 
             // otherwise, we have an 8-bit encoding
             R_len_t curn = LENGTH(curs);
-            const char* curs_tab = CHAR(curs);
+            const char* curs_tab = CHAR(curs);  // TODO: ALTREP will be problematic?
             R_len_t k = 0;
             for (R_len_t j=0; j<curn; ++j) {
                 if (U8_IS_SINGLE(curs_tab[j]))
@@ -297,7 +297,7 @@ SEXP stri_enc_toutf8(SEXP str, SEXP is_unknown_8bit, SEXP validate)
             SEXP curs = STRING_ELT(ret, i);
             if (curs == NA_STRING) continue;
 
-            const char* s = CHAR(curs);
+            const char* s = CHAR(curs);  // TODO: ALTREP will be problematic?
             R_len_t sn = LENGTH(curs);
             R_len_t j = 0;
             UChar32 c = 0;
@@ -364,7 +364,7 @@ SEXP stri_enc_toutf8(SEXP str, SEXP is_unknown_8bit, SEXP validate)
  */
 SEXP stri_enc_toascii(SEXP str)
 {
-    PROTECT(str = stri_prepare_arg_string(str, "str"));
+    PROTECT(str = stri__prepare_arg_string(str, "str"));
     R_len_t n = LENGTH(str);
 
     STRI__ERROR_HANDLER_BEGIN(1)
@@ -393,7 +393,7 @@ SEXP stri_enc_toascii(SEXP str)
         }
 
         R_len_t curn = LENGTH(curs);
-        const char* curs_tab = CHAR(curs);
+        const char* curs_tab = CHAR(curs);  // TODO: ALTREP will be problematic?
 
         if (IS_UTF8(curs)) {
             R_len_t k = 0, j = 0;
@@ -455,7 +455,7 @@ SEXP stri_enc_toascii(SEXP str)
  */
 SEXP stri_encode_from_marked(SEXP str, SEXP to, SEXP to_raw)
 {
-    PROTECT(str = stri_prepare_arg_string(str, "str"));
+    PROTECT(str = stri__prepare_arg_string(str, "str"));
     const char* selected_to   = stri__prepare_arg_enc(to, "to", true); /* this is R_alloc'ed */
     bool to_raw_logical = stri__prepare_arg_logical_1_notNA(to_raw, "to_raw");
 
@@ -580,7 +580,7 @@ SEXP stri_encode(SEXP str, SEXP from, SEXP to, SEXP to_raw)
     bool to_raw_logical = stri__prepare_arg_logical_1_notNA(to_raw, "to_raw");
 
     // raw vector, character vector, or list of raw vectors:
-    PROTECT(str = stri_prepare_arg_list_raw(str, "str"));
+    PROTECT(str = stri__prepare_arg_list_raw(str, "str"));
 
 
     STRI__ERROR_HANDLER_BEGIN(1)
@@ -630,7 +630,7 @@ SEXP stri_encode(SEXP str, SEXP from, SEXP to, SEXP to_raw)
         UErrorCode status = U_ZERO_ERROR;
         UnicodeString encs(curs, curn, uconv_from, status); // FROM -> UTF-16 [this is the slow part]
         if (status == U_ILLEGAL_ARGUMENT_ERROR)
-            throw StriException(MSG__MEM_ALLOC_ERROR);
+            throw StriException(MSG__MEM_ALLOC_ERROR);  // see #395
         STRI__CHECKICUSTATUS_THROW(status, {/* do nothing special on err */})
 
         R_len_t curn_tmp = encs.length();
