@@ -1,5 +1,5 @@
 /* This file is part of the 'stringi' project.
- * Copyright (c) 2013-2020, Marek Gagolewski <https://www.gagolewski.com>
+ * Copyright (c) 2013-2023, Marek Gagolewski <https://www.gagolewski.com/>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -55,7 +55,7 @@
  */
 SEXP stri_stats_general(SEXP str)
 {
-    PROTECT(str = stri_prepare_arg_string(str, "str"));
+    PROTECT(str = stri__prepare_arg_string(str, "str"));
     R_len_t str_length = LENGTH(str);
 
     STRI__ERROR_HANDLER_BEGIN(1)
@@ -140,7 +140,7 @@ SEXP stri_stats_general(SEXP str)
  */
 SEXP stri_stats_latex(SEXP str)
 {
-    PROTECT(str = stri_prepare_arg_string(str, "str"));
+    PROTECT(str = stri__prepare_arg_string(str, "str"));
     R_len_t str_length = LENGTH(str);
 
     STRI__ERROR_HANDLER_BEGIN(1)
